==> haskell-ini-0.4.2-198-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-DlBf5vzyLySGdAPWq1Smqa
key:                  ini-0.4.2-DlBf5vzyLySGdAPWq1Smqa
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  e624b270e9b8af88bd733164993a0b10
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-DlBf5vzyLySGdAPWq1Smqa
depends:
    attoparsec-0.14.4-K96akOPZKYDKXaMIGNQXgm base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.4.2-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-2LIDZZmEhNqB8lWd5UvI4P
key:                  ini-0.4.2-2LIDZZmEhNqB8lWd5UvI4P
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  1af58cb91d19855d144f3fdee8e442d6
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-2LIDZZmEhNqB8lWd5UvI4P
depends:
    attoparsec-0.14.4-IEX5Q72xfrMFJKDYkhuhWv base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
